# This file was auto-generated by Fern from our API Definition.

from ..core.unchecked_base_model import UncheckedBaseModel
from .moderation_status_response_model_safety_status import ModerationStatusResponseModelSafetyStatus
from .moderation_status_response_model_warning_status import ModerationStatusResponseModelWarningStatus
from ..core.pydantic_utilities import IS_PYDANTIC_V2
import typing
import pydantic


class ModerationStatusResponseModel(UncheckedBaseModel):
    is_in_probation: bool
    enterprise_check_nogo_voice: bool
    enterprise_check_block_nogo_voice: bool
    never_live_moderate: bool
    nogo_voice_similar_voice_upload_count: int
    enterprise_background_moderation_enabled: bool
    safety_status: ModerationStatusResponseModelSafetyStatus
    warning_status: ModerationStatusResponseModelWarningStatus
    on_watchlist: bool

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
