# This file was auto-generated by Fern from our API Definition.

from ..core.unchecked_base_model import UncheckedBaseModel
import typing
from .asr_quality import AsrQuality
from .asr_provider import AsrProvider
from .asr_input_format import AsrInputFormat
from ..core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class AsrConversationalConfig(UncheckedBaseModel):
    quality: typing.Optional[AsrQuality] = None
    provider: typing.Optional[AsrProvider] = None
    user_input_audio_format: typing.Optional[AsrInputFormat] = None
    keywords: typing.Optional[typing.List[str]] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
